@@ -10,8 +10,12 @@
 #' @param title App title.
 #' @param old_school Whether to use the wonderful sketchy design for Bootstrap 4. FALSE
 #' by default.
+#' @param sidebar_mini Whether to see sidebar icons when \link{bs4DashSidebar}.
+#' is collapsed. TRUE by default.
 #' @param sidebar_collapsed Whether the sidebar is collapsed of not at start. FALSE by default.
 #' @param controlbar_collapsed Whether the sidebar is collapsed of not at start. TRUE by default.
+#' @param controlbar_overlay Whether the sidebar covers the content when expanded.
+#' Default to TRUE.
 #' @param enable_preloader Whether to enable a page loader. FALSE by default.
 #' @param loading_duration Loader duration in seconds. 2s by default.
 #' @param loading_background  Background color during page startup. Blue by default: 
@@ -41,17 +45,21 @@
 #' @export
 bs4DashPage <- function(navbar = NULL, sidebar = NULL, body = NULL, 
                         controlbar = NULL, footer = NULL, title = NULL,
-                        old_school = FALSE, sidebar_collapsed = FALSE,
-                        controlbar_collapsed = TRUE, enable_preloader = FALSE, 
+                        old_school = FALSE, sidebar_mini = TRUE, 
+                        sidebar_collapsed = FALSE, controlbar_collapsed = TRUE, 
+                        controlbar_overlay = TRUE, enable_preloader = FALSE, 
                         loading_duration = 2, loading_background = "#1E90FF"){
   
-  if (!is.null(sidebar)) {
-    sidebar_cl <- if (sidebar_collapsed) "sidebar-collapse" else "sidebar-open"
-  }
-  if(!is.null(controlbar)) {
+  sidebar_cl <- "layout-fixed"
+  if (sidebar_mini) sidebar_cl <- paste0(sidebar_cl, " sidebar-mini")
+  
+  if (!is.null(controlbar)) {
     if (!controlbar_collapsed) {
       sidebar_cl <- paste0(sidebar_cl, " control-sidebar-slide-open")
     }
+    if (!controlbar_overlay) {
+      sidebar_cl <- paste0(sidebar_cl, " control-sidebar-push-slide")
+    } 
   }
   
   # create the body content
@@ -113,7 +121,8 @@ bs4DashPage <- function(navbar = NULL, sidebar = NULL, body = NULL,
     addDeps(
       theme = old_school,
       shiny::tags$body(
-        class = paste0("hold-transition sidebar-mini ", sidebar_cl),
+        class = sidebar_cl,
+        `sidebar-start-open` = tolower(!sidebar_collapsed),
         
         # set up a time-out for the preloader
         # The body content disappears first,
